==> barcode_scanner-3.1.0-beta2.tar.gz: CHANGELOG.md <==
## 3.1.0 (20 jan 2022)
- 🎉 New:
  * Added ability to disable auto-focus by locking the lens at the specified lens position. See `minFocusDistance` in `BarcodeScannerConfiguration` and `BatchBarcodeScannerConfiguration`
  * Android: Added `lowPowerMode` in `BarcodeScannerAdditionalConfiguration` for `BarcodeScannerConfiguration` and `BatchBarcodeScannerConfiguration`
  * Android: Added ability of Scanbot SDK Core native logging! See `enableNativeLogging ` in `ScanbotSDKInitializer`
- 🚀 Improvements:
  * Improved Aztec barcode recognition.
  * Improved PDF417 recognition performance on single photos.
  * Improved barcode detection on large documents.
  * Improved GS-1 databar recognition in the next-gen barcode scanner.
- 🚙 Under the hood
  * Upgraded the native Scanbot Android SDK to v3.1.0 (cf. [changelog](https://docs.scanbot.io/barcode-scanner-sdk/android/changelog/#version-310-14-jan-2022))
  * Upgraded the native Scanbot iOS SDK to v3.1.0 (cf. [changelog](https://docs.scanbot.io/barcode-scanner-sdk/ios/changelog/#version-303-3-november-2021))
  * Updated some third party libraries. [see Third-party Libraries](100-third-party-libraries.mdx)

## 3.0.2 (23 Dec 2021)
- 🎉 New:
  * Added Document Format filters for Barcode Detection. See `acceptedDocumentFormats` in `BarcodeScannerConfiguration`, `BatchBarcodeScannerConfiguration` and `detectFromImageFile`
  * Android: Added support for GPU and Xnnpack acceleration, and the possibility to use the Camera X module! See `allowGpuAcceleration`, `allowXnnpackAcceleration` and `useCameraXRtuUi` in `ScanbotSDKInitializer`
  * Added support for `stripCheckDigits` and `msiPlesseyChecksumAlgorithms` in `BarcodeAdditionalParameters`
- ⚠️ Breaking Changes:
  * Renamed parameter `enableGS1Decoding` to `gs1DecodingEnabled` in `BarcodeAdditionalParameters`
  * In function `detectFromImageFile`, `barcodeFormats` parameter is changed from a positional parameter to an optional named parameter
- 🚀 Improvements:
  * Significant performance improvements for all scanners
- 🐞 Bug fixes:
  * Barcode Scanner RTU-UI now returns `BarcodeScanningResult.canceled()` instead of an error, when the user cancels the RTU-UI
- 🚙 Under the hood
  * Upgraded the native Scanbot Android SDK to v3.0.6 (cf. [changelog](https://docs.scanbot.io/barcode-scanner-sdk/android/changelog/#version-306-5-nov-2021))
  * Upgraded the native Scanbot iOS SDK to v3.0.3 (cf. [changelog](https://docs.scanbot.io/barcode-scanner-sdk/ios/changelog/#version-303-3-november-2021))
  * Updated some third party libraries. [see Third-party Libraries](100-third-party-libraries.mdx)
  
## 3.0.1
- 🎉 New:
  * iOS: Added support for Apple Silicon M1 simulators. Your app now will run natively on M1 Mac simulators without having to start Xcode in Rosetta 2 mode
- ⚠️ Breaking Changes:
  * iOS: The `ScanbotBarcodeScannerSDK` CocoaPod now contains an XCFramework instead of a standard framework, you may need to update CocoaPods and/or Xcode
- 🚙 Under the hood
  * Updated the native iOS Barcode Scanbot SDK to 3.0.1

## 3.0.0
- 🎉 New:
  * Brand new "Next Generation" machine-learning-based barcode scanning engine with improved reliability and much faster performance 
  * API changes for the new barcode engine: added `engineMode` property of type `EngineMode` on barcode scanning APIs - `BarcodeScannerConfiguration` and `BatchBarcodeScannerConfiguration` to switch between the legacy barcode engine and the new Next Generation barcode engine. By default, the new engine is used.
  * Added the new `cameraZoomFactor` property in `BarcodeScannerConfiguration` for configuring the zoom level of the camera.
  * Encryption for images generated by the SDK. For more details please check out the section "Storage Encryption" of the documentation.
  * Added support for MSI Plessey barcodes.
  * Added `additionalParameters` property to `BarcodeScannerConfiguration` and `BatchBarcodeScannerConfiguration`, which lets you setup a minimum and maximum text length as well as a quiet zone. Currently works for ITF barcodes only.   
- 🚙 Under the hood
  * Updated the native iOS Barcode Scanbot SDK to 3.0.0
  * Updated the native Android Barcode Scanbot SDK to 3.0.1
- ⚠️ Breaking Changes:
  * Removed `enableHighSensitivityMode` property from `BarcodeScannerConfiguration` and `BatchBarcodeScannerConfiguration`, because it is no longer needed
  
## 1.2.0
- 🎉 New:
  * Introduced null safety support for the SDK.

- ⚠️ Breaking Changes:
  * Because of the null safety support, please check compilation issues and warnings from `flutter analyze` command
  * Updated minimum Dart SDK to v2.12.0-0 and Flutter to v2.0.1

## 1.1.0
- 🎉 New:
  - Batch Barcode Scanner - a new RTU UI screen component to scan multiple barcodes in a row. See the new API function startBatchBarcodeScanner.
  - Added a new config property autoCancelTimeout for the Barcode Scanner UI. It provides the possibility to set a timeout value in seconds for auto-closing/cancellation of the Barcode Scanner UI.
New result field BarcodeItem.rawBytes that contains the raw bytes from the scanned barcode
- ⚠️ Breaking Changes:
  - Replaced `finderAspectRatio` parameter with `finderWidth` and `finderHeight` in `BarcodeScannerConfiguration`
- 🚙 Under the hood:
  - Updated the native Android Scanbot Barcode Scanner SDK to 1.3.2
  - Updated the native iOS Scanbot Barcode Scanner SDK to 1.8.4


## 1.0.1
- Improved `pubspec.yaml`, adjusted supported platforms.


## 1.0.0
- 🎉 First release


## 0.9.0-rc.4
- RC4


## 0.9.0-rc.3
- RC3


## 0.9.0-rc.2
- RC2


## 0.9.0-rc.1
- RC1

==> barcode_scanner-3.2.0-beta2.tar.gz: CHANGELOG.md <==
## 3.2.0 (30 June 2022)
- 🎉 New:
  * Introduced Classical Components for Barcode Scanning that allow you to build your own flexible and fully customizable UI for the barcode scanner. `BarcodeScannerCamera`, `BarcodeCameraLiveDetector` and `ScanbotCameraController` to build a custom Barcode and QR-Code scanning.
- 🚀 Improvements:
  * Improved 1D barcode recognition
- ⚠️ Breaking changes:
  * Renamed Disability Certificate to Medical Certificate:
    - `DisabilityCertificateDocument` has been renamed to `MedicalCertificateDocument`
    - `DisabilityCertificateDocumentField` has been renamed to `MedicalCertificateDocumentField`
    - `DisabilityCertificateDocumentFieldType` has been renamed to `MedicalCertificateDocumentFieldType`
- 🚙 Under the hood
  * Upgraded the native Scanbot Android SDK to v3.2.2 (cf. [changelog](https://docs.scanbot.io/barcode-scanner-sdk/android/changelog/#version-322-13-jun-2022))
  * Upgraded the native Scanbot iOS SDK to v3.2.2 (cf. [changelog](https://docs.scanbot.io/barcode-scanner-sdk/ios/changelog/))
  * Updated some third party libraries. [see Third-party Libraries](100-third-party-libraries.mdx)

## 3.1.2 (31 May 2022)
- 🐞 Bug fixes:
  * Fixed compatibility issues with Flutter v3.0.1+

## 3.1.1 (22 March 2022)
- 🐞 Bug fixes:
  * Fixed `LicenseExpirationDate`: Invalid date format.
  * By default, GPU acceleration has been disabled (due to issues on the Samsung S22 series devices). To enable it, use `allowGpuAcceleration: true` in `ScanbotSdkConfig()`.
- 🚙 Under the hood
  * Upgraded the native Scanbot Android SDK to v3.1.2 (cf. [changelog](https://docs.scanbot.io/barcode-scanner-sdk/android/changelog/#version-312-11-mar-2022))
  * Updated some third party libraries. [see Third-party Libraries](100-third-party-libraries.mdx)

## 3.1.0 (4 Feb 2022)
- 🎉 New:
  * Added the ability to disable auto-focus by locking the lens at the specified lens position. See `minFocusDistance` in `BarcodeScannerConfiguration` and `BatchBarcodeScannerConfiguration`
  * Android: Added `lowPowerMode` in `BarcodeScannerAdditionalConfiguration` for `BarcodeScannerConfiguration` and `BatchBarcodeScannerConfiguration`
  * Android: Added the ability for Scanbot SDK Core native logging! See `enableNativeLogging ` in `ScanbotSDKInitializer`
- 🚀 Improvements:
  * Improved Aztec barcode recognition.
  * Improved PDF417 recognition performance on single photos.
  * Improved barcode detection on large documents.
  * Improved GS-1 databar recognition in the next-gen barcode scanner.
- 🚙 Under the hood
  * Upgraded the native Scanbot Android SDK to v3.1.0 (cf. [changelog](https://docs.scanbot.io/barcode-scanner-sdk/android/changelog/#version-310-14-jan-2022))
  * Upgraded the native Scanbot iOS SDK to v3.1.1 (cf. [changelog](https://docs.scanbot.io/barcode-scanner-sdk/ios/changelog/#version-311-26-january-2021))
  * Updated some third party libraries. [see Third-party Libraries](100-third-party-libraries.mdx)

## 3.0.2 (23 Dec 2021)
- 🎉 New:
  * Added Document Format filters for Barcode Detection. See `acceptedDocumentFormats` in `BarcodeScannerConfiguration`, `BatchBarcodeScannerConfiguration` and `detectFromImageFile`
  * Android: Added support for GPU and Xnnpack acceleration, and the possibility to use the Camera X module! See `allowGpuAcceleration`, `allowXnnpackAcceleration` and `useCameraXRtuUi` in `ScanbotSDKInitializer`
  * Added support for `stripCheckDigits` and `msiPlesseyChecksumAlgorithms` in `BarcodeAdditionalParameters`
- ⚠️ Breaking Changes:
  * Renamed parameter `enableGS1Decoding` to `gs1DecodingEnabled` in `BarcodeAdditionalParameters`
  * In function `detectFromImageFile`, `barcodeFormats` parameter is changed from a positional parameter to an optional named parameter
- 🚀 Improvements:
  * Significant performance improvements for all scanners
- 🐞 Bug fixes:
  * Barcode Scanner RTU-UI now returns `BarcodeScanningResult.canceled()` instead of an error, when the user cancels the RTU-UI
- 🚙 Under the hood
  * Upgraded the native Scanbot Android SDK to v3.0.6 (cf. [changelog](https://docs.scanbot.io/barcode-scanner-sdk/android/changelog/#version-306-5-nov-2021))
  * Upgraded the native Scanbot iOS SDK to v3.0.3 (cf. [changelog](https://docs.scanbot.io/barcode-scanner-sdk/ios/changelog/#version-303-3-november-2021))
  * Updated some third party libraries. [see Third-party Libraries](100-third-party-libraries.mdx)

## 3.0.1
- 🎉 New:
  * iOS: Added support for Apple Silicon M1 simulators. Your app now will run natively on M1 Mac simulators without having to start Xcode in Rosetta 2 mode
- ⚠️ Breaking Changes:
  * iOS: The `ScanbotBarcodeScannerSDK` CocoaPod now contains an XCFramework instead of a standard framework, you may need to update CocoaPods and/or Xcode
- 🚙 Under the hood
  * Updated the native iOS Barcode Scanbot SDK to 3.0.1

## 3.0.0
- 🎉 New:
  * Brand new "Next Generation" machine-learning-based barcode scanning engine with improved reliability and much faster performance
  * API changes for the new barcode engine: added `engineMode` property of type `EngineMode` on barcode scanning APIs - `BarcodeScannerConfiguration` and `BatchBarcodeScannerConfiguration` to switch between the legacy barcode engine and the new Next Generation barcode engine. By default, the new engine is used.
  * Added the new `cameraZoomFactor` property in `BarcodeScannerConfiguration` for configuring the zoom level of the camera.
  * Encryption for images generated by the SDK. For more details please check out the section "Storage Encryption" of the documentation.
  * Added support for MSI Plessey barcodes.
  * Added `additionalParameters` property to `BarcodeScannerConfiguration` and `BatchBarcodeScannerConfiguration`, which lets you setup a minimum and maximum text length as well as a quiet zone. Currently works for ITF barcodes only.   
- 🚙 Under the hood
  * Updated the native iOS Barcode Scanbot SDK to 3.0.0
  * Updated the native Android Barcode Scanbot SDK to 3.0.1
- ⚠️ Breaking Changes:
  * Removed `enableHighSensitivityMode` property from `BarcodeScannerConfiguration` and `BatchBarcodeScannerConfiguration`, because it is no longer needed

## 1.2.0
- 🎉 New:
  * Introduced null safety support for the SDK.

- ⚠️ Breaking Changes:
  * Because of the null safety support, please check compilation issues and warnings from `flutter analyze` command
  * Updated minimum Dart SDK to v2.12.0-0 and Flutter to v2.0.1

## 1.1.0
- 🎉 New:
  - Batch Barcode Scanner - a new RTU UI screen component to scan multiple barcodes in a row. See the new API function startBatchBarcodeScanner.
  - Added a new config property autoCancelTimeout for the Barcode Scanner UI. It provides the possibility to set a timeout value in seconds for auto-closing/cancellation of the Barcode Scanner UI.
New result field BarcodeItem.rawBytes that contains the raw bytes from the scanned barcode
- ⚠️ Breaking Changes:
  - Replaced `finderAspectRatio` parameter with `finderWidth` and `finderHeight` in `BarcodeScannerConfiguration`
- 🚙 Under the hood:
  - Updated the native Android Scanbot Barcode Scanner SDK to 1.3.2
  - Updated the native iOS Scanbot Barcode Scanner SDK to 1.8.4


## 1.0.1
- Improved `pubspec.yaml`, adjusted supported platforms.


## 1.0.0
- 🎉 First release


## 0.9.0-rc.4
- RC4


## 0.9.0-rc.3
- RC3


## 0.9.0-rc.2
- RC2


## 0.9.0-rc.1
- RC1
